unit QuickToolsGlobal;

interface

uses
  Windows,
  Menus,
  Forms,
  ComCtrls,
  Classes,
  Registry;

{ QuickTools5History.txt }

const
  QuickToolsBuild='(build 9)';
  QuickToolsVersion='v0.0.1 '+QuickToolsBuild;
  QuickToolsName='QuickTools';
  QuickToolsDate='2001/4/5';

function FindMenuItem(Menu:TMenuItem;Name:String):TMenuItem;
function CompleteMenuName(Menu:TMenuItem;Name:String):String;
function ExecuteMenuItem(Name:String):Boolean;
procedure ReadOptionsFromRegistry;
procedure WriteOptionsToRegistry;

type
  TQuickToolsOptions=record
    CloseDefault:Boolean;
    HideCaptions:Boolean;
    MaximizeEditor:Boolean;
    CreateCompDate:Boolean;
    ChangeIcon:Boolean;
  end;

var
  ProjOptDialog:Boolean;
  Options:TQuickToolsOptions;

implementation

uses
  SysUtils,
  ExptIntf,
  DsgnIntf,
  ToolIntf;

function FindMenuItem(Menu:TMenuItem;Name:String):TMenuItem;
var
  j:Integer;
begin
  Result:=nil;
  for j:=0 to Menu.Count-1 do
  begin
    if Menu.Items[j].Name=Name then
      Result:=Menu.Items[j]
    else if Menu.Items[j].Count>0 then
      Result:=FindMenuItem(Menu.Items[j],Name);
    if Result<>nil then
      break;
  end;
end;

function CompleteMenuName(Menu:TMenuItem;Name:String):String;
var
  j:Integer;
begin
  Result:='';
  for j:=0 to Menu.Count-1 do
  begin
    if Pos(UpperCase(Name),UpperCase(Menu.Items[j].Name))>0 then
      Result:=Menu.Items[j].Name
    else if Menu.Items[j].Count>0 then
      Result:=CompleteMenuName(Menu.Items[j],Name);
    if Result<>'' then
      break;
  end;
end;

function ExecuteMenuItem(Name:String):Boolean;
var
  Menu:TMenuItem;
begin
  Menu:=FindMenuItem(Application.MainForm.Menu.Items,Name);
  Result:=(Menu<>nil);
  if Menu<>nil then
    Menu.Click;
end;

procedure SetProjOptDialog;
var
  i:Integer;
begin
  ProjOptDialog:=false;
  for i:=0 to Screen.FormCount-1 do
  begin
    if Screen.Forms[i].Name='ProjectOptionsDialog' then
    begin
      ProjOptDialog:=true;
      break;
    end;
  end;
end;

procedure ReadOptionsFromRegistry;
var
  Reg:TRegistry;
begin
  Options.CloseDefault:=true;
  Options.HideCaptions:=false;
  Options.MaximizeEditor:=false;
  Options.CreateCompDate:=true;
  Options.ChangeIcon:=false;

  Reg:=TRegistry.Create;
  try
    Reg.RootKey:=HKEY_CURRENT_USER;
    if Reg.OpenKey('\Software\Borland\Delphi\5.0\QuickTools',false) then
    begin
      try Options.CloseDefault:=Reg.ReadBool('CloseDefault');
      finally end;
      try Options.HideCaptions:=Reg.ReadBool('HideCaptions');
      finally end;
      try Options.MaximizeEditor:=Reg.ReadBool('MaximizeEditor');
      finally end;
      try Options.CreateCompDate:=Reg.ReadBool('CreateCompDate');
      finally end;
      try Options.ChangeIcon:=Reg.ReadBool('ChangeIcon');
      finally end;
      Reg.CloseKey;
    end;
  finally
    Reg.Free;
  end;
end;

procedure WriteOptionsToRegistry;
var
  Reg:TRegistry;
begin
  Reg:=TRegistry.Create;
  try
    Reg.RootKey:=HKEY_CURRENT_USER;
    if Reg.OpenKey('\Software\Borland\Delphi\5.0\QuickTools',true) then
    begin
      try Reg.WriteBool('CloseDefault',Options.CloseDefault);
      finally end;
      try Reg.WriteBool('HideCaptions',Options.HideCaptions);
      finally end;
      try Reg.WriteBool('MaximizeEditor',Options.MaximizeEditor);
      finally end;
      try Reg.WriteBool('CreateCompDate',Options.CreateCompDate);
      finally end;
      try Reg.WriteBool('ChangeIcon',Options.CloseDefault);
      finally end;
      Reg.CloseKey;
    end;
  finally
    Reg.Free;
  end;
end;

initialization
  SetProjOptDialog;
  ReadOptionsFromRegistry;
finalization
end.

